@@ -1,14 +1,14 @@
 /*                     __                                               *\
 **     ________ ___   / /  ___     Scala API                            **
-**    / __/ __// _ | / /  / _ |    (c) 2002, LAMP/EPFL                  **
+**    / __/ __// _ | / /  / _ |    (c) 2002-2004, LAMP/EPFL             **
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: AnyVal.java,v 1.2 2004/06/22 11:36:41 paltherr Exp $
+// $Id: AnyVal.java,v 1.3 2004/09/29 16:05:50 michelou Exp $
 
 package scala;
 
 /** @meta class extends scala.Any; */
-public abstract class AnyVal {}
+public abstract class AnyVal implements java.io.Serializable {}
