@@ -1,10 +1,10 @@
 /*                     __                                               *\
 **     ________ ___   / /  ___     Scala API                            **
-**    / __/ __// _ | / /  / _ |    (c) 2002-2003, LAMP/EPFL             **
+**    / __/ __// _ | / /  / _ |    (c) 2002-2004, LAMP/EPFL             **
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: CaseClass.scala,v 1.9 2004/08/24 15:37:24 paltherr Exp $
+** $Id: CaseClass.scala,v 1.10 2004/09/29 16:05:51 michelou Exp $
 \*                                                                      */
 
 package scala;
@@ -13,7 +13,7 @@ package scala;
  *
  *  @author  Burak Emir
  */
-trait CaseClass {
+trait CaseClass with java.io.Serializable {
 
   /** for a case class A(x_0,...,x_(k-1)), returns x_i for 0 &lt;= i &lt; k,
   **  null otherwise
