@@ -7,7 +7,7 @@
 \*                                                                      */
 
 // $OldId: RunTime.java,v 1.13 2002/11/19 12:01:40 paltherr Exp $
-// $Id: RunTime.java,v 1.17 2004/07/06 07:43:40 paltherr Exp $
+// $Id: RunTime.java,v 1.18 2004/11/17 12:44:39 paltherr Exp $
 
 package scala.runtime;
 
@@ -71,6 +71,18 @@ public abstract class RunTime {
         RunTime.loader = loader;
     }
 
+    //########################################################################
+    // Public Functions - Catching exceptions
+
+    public static Throwable tryCatch(Runnable runnable) {
+	try {
+	    runnable.run();
+            return null;
+	} catch (Throwable exception) {
+	    return exception;
+	}
+    }
+
     //########################################################################
     // Public Functions - Boxing primitives
 
