@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: Text.scala,v 1.14 2004/06/22 21:21:44 buraq Exp $
+** $Id: Text.scala,v 1.15 2004/10/27 10:43:18 buraq Exp $
 \*                                                                      */
 
 package scala.xml;
@@ -13,11 +13,14 @@ import scala.collection.immutable ;
 /** an XML node for text (PCDATA). Used in both non-bound and bound XML 
  *  representations
  * @author Burak Emir
- * @param text the text contained in this node
+ * @param text the text contained in this node, may not be null.
 **/
 
 case class Text( text:String ) extends SpecialNode {  
 
+  if(null == text)
+    throw new java.lang.NullPointerException("tried to construct Text with null");
+
   final override def typeTag$:Int = -1;
 
   /** the constant "#PCDATA"
